@@ -120,7 +120,7 @@ impl GeneralReadout for FreeBSDGeneralReadout {
     }
 
     fn resolution(&self) -> Result<String, ReadoutError> {
-        Err(ReadoutError::MetricNotAvailable)
+        crate::shared::resolution()
     }
 
     fn backlight(&self) -> Result<usize, ReadoutError> {
@@ -321,7 +321,7 @@ impl ProductReadout for FreeBSDProductReadout {
         FreeBSDProductReadout
     }
 
-    fn version(&self) -> Result<String, ReadoutError> {
+    fn family(&self) -> Result<String, ReadoutError> {
         Err(ReadoutError::MetricNotAvailable)
     }
 
